@@ -10,7 +10,7 @@ from decimal import Decimal
 
 import proteus.config
 
-__version__ = "5.0.13"
+__version__ = "5.2.1"
 __all__ = ['Model', 'Wizard', 'Report']
 
 _MODELS = threading.local()
@@ -25,8 +25,6 @@ class _EvalEnvironment(dict):
         self.eval_type = eval_type
 
     def __getitem__(self, item):
-        if item == 'id':
-            return self.parent.id
         if item == '_parent_' + self.parent._parent_name \
                 and self.parent._parent:
             return _EvalEnvironment(self.parent._parent,
@@ -58,8 +56,6 @@ class _EvalEnvironment(dict):
     __repr__ = __str__
 
     def __contains__(self, item):
-        if item == 'id':
-            return True
         if item == '_parent_' + self.parent._parent_name \
                 and self.parent._parent:
             return True
@@ -110,12 +106,12 @@ class FieldDescriptor(object):
         self.__doc__ = definition['string']
 
     def __get__(self, instance, owner):
-        if instance.id >= 0:
+        if instance.id > 0:
             instance._read(self.name)
         return instance._values.get(self.name, self.default)
 
     def __set__(self, instance, value):
-        if instance.id >= 0:
+        if instance.id > 0:
             instance._read(self.name)
         previous = getattr(instance, self.name)
         instance._values[self.name] = value
@@ -662,9 +658,9 @@ class Model(object):
 
     def __init__(self, id=None, _default=True, _group=None, **kwargs):
         super(Model, self).__init__()
-        if id is not None:
+        if id:
             assert not kwargs
-        self.__id = id if id is not None else Model.__counter
+        self.__id = id or Model.__counter
         if self.__id < 0:
             Model.__counter -= 1
         self._values = {}  # store the values of fields
@@ -846,7 +842,7 @@ class Model(object):
             assert proxy == record._proxy
             assert config == record._config
             assert context == record._context
-            if record.id >= 0:
+            if record.id > 0:
                 timestamp.update(record._get_timestamp())
                 delete.append(record.id)
         context['_timestamp'] = timestamp
@@ -929,7 +925,8 @@ class Model(object):
         if loading == 'eager':
             fields = [x for x, y in self._fields.items()
                     if y['loading'] == 'eager']
-        fields.append('_timestamp')
+        if not self._fields:
+            fields.append('_timestamp')
         self._values.update(
             self._proxy.read([self.id], fields, self._context)[0])
         for field in fields:
@@ -1006,16 +1003,6 @@ class Model(object):
         return values
 
     def _on_change_args(self, args):
-        # Ensure arguments has been read
-        for arg in args:
-            record = self
-            for i in arg.split('.'):
-                if i in record._fields:
-                    getattr(record, i)
-                elif i == '_parent_' + record._parent_name:
-                    getattr(record, record._parent_name)
-                    record = record._parent
-
         res = {}
         values = _EvalEnvironment(self, 'on_change')
         for arg in args:
@@ -1026,7 +1013,6 @@ class Model(object):
                 scope = scope[i]
             else:
                 res[arg] = scope
-        res['id'] = self.id
         return res
 
     def _on_change_set(self, field, value):
@@ -1235,15 +1221,10 @@ class Report(object):
         self._proxy = self._config.get_proxy(name, type='report')
 
     def execute(self, models=None, data=None):
-        if models:
-            ids = [m.id for m in models]
-        elif data:
-            ids = data.get('ids', [])
-        else:
-            ids = []
+        ids = [m.id for m in models] if models else data.get('ids', [])
         if data is None:
             data = {
-                'id': ids[0] if ids else None,
+                'id': ids[0],
                 'ids': ids,
                 }
             if models:
@@ -1294,8 +1275,6 @@ def _convert_action(action, data=None, context=None, config=None):
         with config.reset_context(), config.set_context(action_ctx):
             if res_id is None:
                 return Model_.find(domain)
-            elif isinstance(res_id, int):
-                return [Model_(res_id)]
             else:
                 return [Model_(id_) for id_ in res_id]
     elif action['type'] == 'ir.action.wizard':
